/**
	$Id: AbstractJspActionFactory.java 4512 2008-09-11 20:05:50Z jari $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.skin;

import java.util.Iterator;

import net.sf.basedb.clients.web.extensions.AbstractJspActionFactory;
import net.sf.basedb.clients.web.extensions.DynamicActionAttribute;
import net.sf.basedb.clients.web.extensions.DynamicActionAttributes;
import net.sf.basedb.clients.web.extensions.ExtensionsControl;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.extensions.xml.PathSetter;
import net.sf.basedb.util.extensions.xml.VariableSetter;

/**
	A simple action factory implementation that always include the
	given skin on all pages. It supports dynamic attributes, favicon
	and image re-mapping. To use image remapping, set the 
	&lt;image-remap-dir&gt; parameter in the configuration file to
	a path in the /resources dir in the JAR file but without the /resources
	prefix. For example, if the images to remap are in the 
	/resources/images/remap directory set the parameter to /images/remap.
	
	@author nicklas
	@since 3.4
*/
public class FixedSkinActionFactory
	extends AbstractJspActionFactory<SkinAction>
{
	
	private String id;
	
	private String favicon;
	
	private String remapDir;
	
	/**
		Create a new factory instance.
	*/
	public FixedSkinActionFactory()
	{}
	
	/*
		From the ActionFactory interface
		--------------------------------
	*/
	/**
		@return Always an array with a single element
	*/
	@Override
	public SkinAction[] getActions(InvokationContext<? super SkinAction> context)
	{
		return new SkinAction[] { new MySkinAction(this, context.getExtension().getId()) };
	}
	// ----------------------------------

	public String getId()
	{
		return id;
	}
	
	public void setId(String id)
	{
		this.id = id;
	}
	
	public String getFavicon()
	{
		return favicon;
	}
	
	@PathSetter
	@VariableSetter
	public void setFavicon(String favicon)
	{
		this.favicon = favicon;
	}
	
	public void setImageRemapDir(String remapDir)
	{
		this.remapDir = remapDir;
	}
	
	public String getImageRemapDir()
	{
		return remapDir;
	}
	
	static class MySkinAction
		implements SkinAction, DynamicActionAttributes
	{
		private final FixedSkinActionFactory factory;
		private final String xtId;
		
		MySkinAction(FixedSkinActionFactory factory, String xtId)
		{
			this.factory = factory;
			this.xtId = xtId;
		}

		@Override
		public String getId() 
		{
			return factory.getId();
		}

		@Override
		public String getFavicon() 
		{
			return factory.getFavicon();
		}

		@Override
		public void remapImages(ImageRemapper mapper) 
		{
			if (factory.getImageRemapDir() != null)
			{
				String path = ExtensionsControl.getHomeUrl(xtId) + factory.getImageRemapDir();
				ImageRemapperUtil.remapAllTo(mapper, path);
			}
		}

		@Override
		public Iterator<DynamicActionAttribute> getDynamicActionAttributes()
		{
			return factory.getDynamicActionAttributes();
		}
		
	}
}
