/*
	$Id: Orders.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import net.sf.basedb.core.InvalidDataException;
import net.sf.basedb.core.InvalidUseOfNullException;

/**
	A factory class to create order by expressions.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (må, 06 apr 2009) $
*/
public class Orders
{

	/**
		Sort the result of a query in ascending order by the expression.
		@param e The expression to use for sorting
		@see Query#order(Order)
		@throws InvalidDataException If the expression is null
	*/
	public static Order asc(Expression e)
		throws InvalidDataException
	{
		if (e == null) throw new InvalidUseOfNullException("e");
		return new AscOrder(e);
	}

	/**
		Sort the result of a query in descending order by the expression.
		@param e The expression to use for sorting
		@see Query#order(Order)
		@throws InvalidDataException If the expression is null
	*/
	public static Order desc(Expression e)
		throws InvalidDataException
	{
		if (e == null) throw new InvalidUseOfNullException("e");
		return new DescOrder(e);
	}

}
