/**
	$Id: LocalSignalTransporter.java 6444 2014-04-09 12:21:20Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.signal;

/**
	A signal transporter implementation that can transport signals within
	the local virtual machine only. The corresponding receiver class
	is {@link LocalSignalReceiver}.

	@author nicklas
	@version 2.6
	@base.modified $Date: 2014-04-09 14:21:20 +0200 (on, 09 apr 2014) $
*/
public class LocalSignalTransporter
	extends AbstractSignalTransporter
{
	/**
		Log signals processing.
	*/
	private static final org.slf4j.Logger logger = 
		org.slf4j.LoggerFactory.getLogger(LocalSignalTransporter.class);

	/**
		Create a new signal transporter instance.
	*/
	public LocalSignalTransporter()
	{}
	
	/*
		From the SignalTransporter interface
		-------------------------------------------
	*/
	/**
		Send the signal to a local signal receiver. This method will call
		{@link LocalSignalReceiver#getSignalReceiver(String)} to find a registered
		signal receiver and then call {@link LocalSignalReceiver#send(String, Signal)}.
		The signal is sent and processed by the signal handler in the current thread.
	*/
	@Override
	public void send(Signal signal)
	{
		logger.info("Sending signal " + signal.getId() + " to " + getGlobalSignalId());
		LocalSignalReceiver receiver = LocalSignalReceiver.getSignalReceiver(getReceiverId());
		if (receiver != null) receiver.send(getHandlerId(), signal);
	}
	// -------------------------------------------

}
