/**
	$Id: FileWrapper.java 5374 2010-08-03 09:21:30Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.importer;

import java.io.IOException;
import java.io.InputStream;

/**
	Wrapper around files that provide some basic information about the file.
	This allows us to work with both files on disk and in the BASE file system
	without handling special cases.

	@author Nicklas
	@since 2.16
	@base.modified $Date: 2010-08-03 11:21:30 +0200 (ti, 03 aug 2010) $
*/
public interface FileWrapper
{
	
	/**
		Get the name of the file.
		@return The name of the file, or null if not known
	*/
	public String getName();
	
	/**
		Get the size of the file.
		@return The size of the file, or -1 if not known
	*/
	public long getSize();
	
	/**
		Get the character set used in the file.
		@return The character set, or null if not known or if the file is binary file
	*/
	public String getCharacterSet();
	
	/**
		Get an input stream that reads data from the file.
		Multiple calls to this method should normally result in
		multiple independent streams.
		@return An input stream
	*/
	public InputStream getInputStream()
		throws IOException;
	
}
