/**
	$Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.listable;

import java.util.Set;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.PhysicalBioAssay;
import net.sf.basedb.core.query.Expressions;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.Restrictions;

/**
	Source item transformer implementation that transform extract items to physical bioassays. 
	
	@author Nicklas
	@since 3.5
*/
public class ExtractToPhysicalBioAssayTransformer 
	extends AbstractSourceItemTransformer
{

	/**
		Create a new extract to physical bioassay transformer.
	*/
	public ExtractToPhysicalBioAssayTransformer() 
	{
		super(Item.EXTRACT, Item.PHYSICALBIOASSAY);
	}
	
	@Override
	public Set<Integer> transform(TransformContext context, Set<Integer> source) 
	{
		DbControl dc = context.getDbControl();
		
		ItemQuery<PhysicalBioAssay> query = PhysicalBioAssay.getQuery();
		query.setIncludes(context.getInclude());
		query.join(Hql.innerJoin("creationEvent", "ce"));
		query.join(Hql.innerJoin("ce", "sources", "sbm"));
		query.join(Hql.innerJoin("sbm", "bioMaterial", "bm"));
		query.restrict(
			Restrictions.in(
				Hql.alias("bm"), 
				Expressions.parameter("parents")
			));
		return safeIdList(context.getDbControl(), query, "parents", source);
	}


}
