/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var SubTypes = function()
{
	var subTypes = {};
	var itemTypes;
	var itemInfo;
	
	/**
		Initialize the page.
	*/
	subTypes.initPage = function()
	{
		var pageId = Doc.getPageId();		
		if (pageId == 'edit-page')
		{
			// Load info about subtype relationships and capabilities
			itemInfo = Data.json('page-data', 'item-info');
			itemTypes = Data.json('page-data', 'item-types');
			
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', subTypes.save);
			Buttons.addClickHandler('close', App.closeWindow);
			
			// Tab validation
			TabControl.addTabValidator('settings.info', subTypes.validateItemSubtype);
			
			Events.addEventHandler('itemType', 'change', subTypes.itemTypeOnChange);
			
			// Associated subtypes
			for (var i=0; i < itemTypes.length; i++)
			{
				Buttons.addClickHandler('related.'+itemTypes[i]+'.select', subTypes.relatedItemOnClick)
				Events.addEventHandler('related.'+itemTypes[i], 'base-selected', subTypes.relatedItemSelected);
			}
			subTypes.itemTypeOnChange();
			
			// File types
			Buttons.addClickHandler('btnAddFileTypes', subTypes.addFileTypesOnClick);
			Events.addEventHandler('btnAddFileTypes', 'base-selected', subTypes.fileTypeSelected);
			Events.addEventHandler('fileTypes', 'change', subTypes.fileTypesOnChange);
			Buttons.addClickHandler('required', subTypes.requiredOnClick);
			Buttons.addClickHandler('multiple', subTypes.requiredOnClick);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'ITEMSUBTYPE', 'item-id': itemId};
			
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);	
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'ITEMSUBTYPE'};
			var tableAttributes = {'table-id': 'subtypes'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);
			
			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
	
	subTypes.validateItemSubtype = function()
	{
		var frm = document.forms['subtype'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}

	// Submit the form
	subTypes.save = function()
	{
		var frm = document.forms['subtype'];
		if (TabControl.validateActiveTab('settings'))
		{
			Link.exportActions('fileTypes');
			frm.submit();
		}
	}
	
	/**
		Get the current main item type of the subtype that is being
		edited. For existing items, this is stored in the 'page-data' tag,
		for new items, the current selection from the 'itemType' list
		is used.
	*/
	subTypes.getCurrentItemType = function()
	{
		var frm = document.forms['subtype'];
		var itemType = Data.get('page-data', 'main-item-type');
		if (!itemType)
		{
			itemType = frm.itemType.value;
		}
		return itemType;
	}

	/**
		Event handler called when changing the main item type. This
		hide or show other 'related subtypes' sections depending on
		which other item types that can be associated with the main
		item type.
	*/
	subTypes.itemTypeOnChange = function()
	{
		var itemType = subTypes.getCurrentItemType();
		
		for (var i = 0; i < itemTypes.length; i++)
		{
			var item = itemTypes[i];
			Doc.showHide('section.'+item, itemInfo[itemType].related.indexOf(item) >= 0)
		}
		Doc.showHide('section.none', itemInfo[itemType].related.length == 0);
		
		if (itemInfo[itemType].fileStoreEnabled)
		{
			Doc.show('filetypes.enabled');
			Doc.hide('filetypes.disabled');
		}
		else
		{
			Doc.hide('filetypes.enabled');
			Doc.show('filetypes.disabled');
			Doc.element('filetypes.disabled').innerHTML = '<div class="messagecontainer error">The selected main item type (' + itemType + ') has not support for attaching data files.</div>';
		}
		Doc.showHide('section.pushAnnotations', itemInfo[itemType].supportsPushAnnotations);
	}
	
	/**
		Click handler for opening a popup window for selecting a
		related item subtype.
	 */
	subTypes.relatedItemOnClick = function(event)
	{
		var frm = document.forms['subtype'];
		var listName = Data.get(event.currentTarget, 'list-name');
		var itemType = Data.get(listName, 'item-type');
		
		var url = '&resetTemporary=1&tmpfilter:INT:itemType=' + itemInfo[itemType].value;
		if (frm[listName].length > 1) 
		{
			var id = Math.abs(parseInt(frm[listName].value));				
			url += '&item_id='+id;
		}
		url += '&exclude='+Data.get('page-data', 'subtype-id');
		Dialogs.selectItem('ITEMSUBTYPE', listName, 0, url);
	}

	/**
		Callback function for setting the selected related subtype.
	*/
	subTypes.relatedItemSelected = function(event)
	{
		var frm = document.forms['subtype'];
		var list = frm[event.currentTarget.id];
		if (list.length < 2 || list[1].value == '0') 
		{
			Forms.addListOption(list, 1, new Option());
		}
		list[1].value = event.detail.id;
		list[1].text = event.detail.name;
		list.selectedIndex = 1;
	}

	/**
		Open a popup dialog for selecting related file types.
	*/
	subTypes.addFileTypesOnClick = function(event)
	{
		var frm = document.forms['subtype'];
		var itemType = subTypes.getCurrentItemType();
		var currentFileTypes = Link.getIdsInList(frm.fileTypes, 'DATAFILETYPE');
		var excludes = currentFileTypes.join(',');
		var url = '&resetTemporary=1&tmpfilter:INT:itemType=' + itemInfo[itemType].value;
		url += "&exclude="+excludes;
		Dialogs.selectItem('DATAFILETYPE', event.currentTarget.id, 1, url);
	}

	/**
		Callback for adding selected file types to the list.
	 */
	subTypes.fileTypeSelected = function(event)
	{
		var frm = document.forms['subtype'];
		var required = frm.required.checked;
		var multiple = frm.multiple.checked;

		var detail = event.detail;
		var newValue = 0;
		if (required) newValue += 1;
		if (multiple) newValue += 2;
		
		detail.name += required ? ' [×]' : ' [-]';
		detail.value = newValue;
		
		Link.addItem('fileTypes', 'DATAFILETYPE', event.detail);
	}
	
	/**
		Event handler when a file type is selected that update the 'require' and
		'multiple' checkboxes with the current status.
	 */
	subTypes.fileTypesOnChange = function()
	{
		var frm = document.forms['subtype'];
		var item = frm.fileTypes[frm.fileTypes.selectedIndex].item;
		if (item && item.id)
		{
			frm.required.checked = (item.value & 1) > 0;
			frm.multiple.checked = (item.value & 2) > 0;
		}
		else
		{
			frm.required.checked = false;
			frm.multiple.checked = false;
		}
	}

	/**
		Event handler for the 'required' and 'multiple' checkboxes that update
		the status for the selected file types in the list.
	 */
	subTypes.requiredOnClick = function()
	{
		var frm = document.forms['subtype'];
		var required = frm.required.checked;
		var multiple = frm.multiple.checked;
		var newValue = 0;
		if (required) newValue += 1;
		if (multiple) newValue += 2;
		for (var i = 0; i < frm.fileTypes.length; i++)
		{
			var option = frm.fileTypes[i];
			if (option.selected && option.item.id)
			{
				option.item.value = newValue;
				var text = option.text.replace(/\[.*\]/, '['+(required ? '×' : '-') +']');
				option.text = text; 
			}
		}
	}
	

	return subTypes;
}();

Doc.onLoad(SubTypes.initPage);
